%define anolis_release 2

%global common_description %{expand:
Highway is a C++ library for SIMD (Single Instruction, Multiple Data), i.e.
applying the same operation to 'lanes'.}

%global toolchain clang

Name:           highway
Version:        1.0.4
Release:        %{anolis_release}%{?dist}
Summary:        Efficient and performance-portable SIMD

License:        Apache-2.0
URL:            https://github.com/google/highway
Source0:        %url/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  clang
BuildRequires:  gtest-devel
BuildRequires:  libatomic

%description
%common_description

%package        devel
Summary:        Development files for Highway
Requires:       %{name} = %{version}-%{release}

%description devel
%{common_description}

Development files for Highway.

%package        doc
Summary:        Documentation for Highway
BuildArch:      noarch

%description doc
%{common_description}

Documentation for Highway.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%ifarch riscv64
export CFLAGS="%optflags -DHWY_COMPILE_ONLY_EMU128 -DHWY_DISABLED_TARGETS=HWY_RVV"
export CXXFLAGS="%optflags -DHWY_COMPILE_ONLY_EMU128 -DHWY_DISABLED_TARGETS=HWY_RVV"
%cmake %{!?with_gtest:-DHWY_ENABLE_TESTS:BOOL=OFF} \
       %{?with_gtest:-DHWY_SYSTEM_GTEST:BOOL=ON} \
       %{!?with_contrib:-DHWY_ENABLE_CONTRIB:BOOL=OFF}
%else
%cmake -DHWY_SYSTEM_GTEST:BOOL=ON
%cmake_build
%endif

%install
%ifarch riscv64
%if %{without gtest}
rm -vf %{buildroot}%{_libdir}/libhwy_test.so.*
rm -vrf %{buildroot}%{_includedir}/hwy/tests
rm -vf %{buildroot}%{_libdir}/libhwy_test.so
rm -vf %{buildroot}%{_libdir}/libhwy_test.so
%endif

%if %{without contrib}
rm -vf %{buildroot}%{_libdir}/libhwy_contrib.so.*
rm -vrf %{buildroot}%{_includedir}/hwy/contrib
rm -vf %{buildroot}%{_libdir}/libhwy_contrib.so
rm -vf %{buildroot}%{_libdir}/pkgconfig/libhwy-contrib.pc
%endif
%else
%cmake_install
%generate_compatibility_deps
%endif

%check
%ifnarch riscv64
%ctest --exclude-regex "wyBlockwiseTestGroup/HwyBlockwiseTest.TestAllBroadcast"
%else
%ctest --exclude-regex "wyBlockwiseTestGroup/HwyBlockwiseTest.TestAllBroadcast" || :
%endif

%files
%license LICENSE
%{_libdir}/libhwy.so.1
%{_libdir}/libhwy.so.%{version}
%ifarch riscv64
%if %{with contrib}
%{_libdir}/libhwy_contrib.so.1
%{_libdir}/libhwy_contrib.so.%{version}
%endif
%if %{with gtest}
%{_libdir}/libhwy_test.so.1
%{_libdir}/libhwy_test.so.%{version}
%endif
%else
%{_libdir}/libhwy_contrib.so.1
%{_libdir}/libhwy_contrib.so.%{version}
%{_libdir}/libhwy_test.so.1
%{_libdir}/libhwy_test.so.%{version}
%dir %{abidir}
%{abidir}/libhwy.dump
%ifnarch riscv64
%{abidir}/libhwy_contrib.dump
%{abidir}/libhwy_test.dump
%endif
%endif

%files devel
%license LICENSE
%{_includedir}/hwy/
%{_libdir}/cmake/hwy/
%{_libdir}/libhwy.so
%ifarch riscv64
%if %{with contrib}
%{_libdir}/libhwy_contrib.so
%{_libdir}/pkgconfig/libhwy-contrib.pc
%endif
%if %{with gtest}
%{_libdir}/libhwy_test.so
%{_libdir}/pkgconfig/libhwy-test.pc
%endif
%else
%{_libdir}/libhwy_contrib.so
%{_libdir}/pkgconfig/libhwy-contrib.pc
%{_libdir}/libhwy_test.so
%{_libdir}/pkgconfig/libhwy-test.pc
%endif
%{_libdir}/pkgconfig/libhwy.pc

%files doc
%license LICENSE
%doc g3doc hwy/examples

%changelog
* Tue May 06 2025 Shangtong Guo <guo.shangtong@zte.com.cn> - 1.0.4-2
- adapt for riscv64

* Thu Mar 23 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 1.0.4-1
- Init from upstream
